%global srcname uutf

%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif
 
Name:           ocaml-uutf
Version:        1.0.4
Release:        %mkrel 1
Summary:        Non-blocking streaming codec for UTF-8, UTF-16, UTF-16LE and UTF-16BE
License:        BSD3
Group:          Development/OCaml
URL:            https://erratique.ch/software/uutf
Source0:        https://github.com/dbuenzli/uutf/archive/v%{version}/%{srcname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.08.0
BuildRequires:  ocaml-cmdliner-devel >= 1.3.0
BuildRequires:  ocaml-findlib
BuildRequires:  ocaml-ocamlbuild
BuildRequires:  ocaml-ocamldoc
BuildRequires:  ocaml-rpm-macros
BuildRequires:  ocaml-topkg-devel >= 1.0.3

%description
Uutf is a non-blocking streaming codec to decode and encode the UTF-8,
UTF-16, UTF-16LE and UTF-16BE encoding schemes.  It can efficiently work
character by character without blocking on I/O.  Decoders perform
character position tracking and support newline normalization.

Functions are also provided to fold over the characters of UTF-encoded
OCaml string values and to directly encode characters in OCaml Buffer.t
values.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n uutf-%{version} -p1

%conf
# Topkg does watermark replacements only if run inside a git checkout.  Github
# tarballs do not come with a .git directory.  Therefore, we do the watermark
# replacement manually.
for fil in $(find . -type f); do
  sed -e 's,%%%%VERSION%%%%,v%{version},' \
      -e 's,%%%%VERSION_NUM%%%%,%{version},' \
      -i.orig $fil
  touch -r $fil.orig $fil
  rm $fil.orig
done

%build
# Build the library and the tests
ocaml pkg/pkg.ml build --dev-pkg false --tests true --with-cmdliner true

# Build the documentation
mkdir html
ocamldoc -html -d html -I _build/src _build/src/uutf.mli

%install
%ocaml_install

%check
ocaml pkg/pkg.ml test

%files -f .ofiles
%doc CHANGES.md README.md
%license LICENSE.md

%files devel -f .ofiles-devel
%doc html/*



%changelog
* Fri Apr 04 2025 pterjan <pterjan> 1.0.4-1.mga10
+ Revision: 2173499
- Update to 1.0.4

* Thu May 19 2022 pterjan <pterjan> 1.0.3-2.mga9
+ Revision: 1859176
- Rebuild for OCaml 4.14

* Tue May 17 2022 pterjan <pterjan> 1.0.3-1.mga9
+ Revision: 1858480
- Update to 1.0.3

* Wed Oct 13 2021 tv <tv> 1.0.2-6.mga9
+ Revision: 1751048
- Rebuild for ocaml 4.13.1

* Thu Mar 04 2021 tv <tv> 1.0.2-5.mga9
+ Revision: 1698686
- rebuild for ocaml-4.2-12

* Sun Jan 10 2021 pterjan <pterjan> 1.0.2-4.mga8
+ Revision: 1670677
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.0.2-3.mga8
+ Revision: 1551668
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.0.2-2.mga8
+ Revision: 1543646
- Mageia 8 Mass Rebuild

* Wed Jan 22 2020 tv <tv> 1.0.2-1.mga8
+ Revision: 1482007
- new release + rebuild for ocaml-4.10

* Tue Oct 23 2018 pterjan <pterjan> 1.0.1-2.mga7
+ Revision: 1324544
- Rebuild for ocaml 4.07.1

* Wed Aug 29 2018 daviddavid <daviddavid> 1.0.1-1.mga7
+ Revision: 1255534
- new version: 1.0.1
- need ocaml-compiler and ocaml-topkg

* Wed Aug 29 2018 daviddavid <daviddavid> 0.9.4-5.mga7
+ Revision: 1255397
- rebuild for new ocaml-result 1.3

* Sat Mar 24 2018 daviddavid <daviddavid> 0.9.4-4.mga7
+ Revision: 1211799
- rebuild for new ocaml-cmdliner

* Mon Jan 22 2018 tv <tv> 0.9.4-3.mga7
+ Revision: 1196248
- BR ocamlbuild
- fix build with ocaml-4.06
- rebuild for new ocaml

* Fri Oct 06 2017 daviddavid <daviddavid> 0.9.4-2.mga7
+ Revision: 1169711
- enable debugging information thus fixing empty debugsourcefiles.list

* Tue Feb 09 2016 pterjan <pterjan> 0.9.4-1.mga6
+ Revision: 951009
- Fix BuildRequires
- Update to 0.9.4

* Wed Oct 15 2014 umeabot <umeabot> 0.9.3-5.mga5
+ Revision: 749971
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.3-4.mga5
+ Revision: 683126
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 0.9.3-3.mga4
+ Revision: 537831
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 blue_prawn <blue_prawn> 0.9.3-2.mga4
+ Revision: 487866
- rebuild for ocaml-4.01.0

* Fri Sep 06 2013 blue_prawn <blue_prawn> 0.9.3-1.mga4
+ Revision: 475540
- updated to last version 0.9.3

* Sun Jan 13 2013 umeabot <umeabot> 0.9.2-2.mga3
+ Revision: 361693
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 malo <malo> 0.9.2-1.mga3
+ Revision: 341176
- new version 0.9.2

* Mon Oct 01 2012 blue_prawn <blue_prawn> 0.9.1-4.mga3
+ Revision: 301077
- rebuild for ocaml-4.00.0

* Sat Sep 29 2012 blue_prawn <blue_prawn> 0.9.1-3.mga3
+ Revision: 300427
- increm mkrel

* Fri Sep 28 2012 blue_prawn <blue_prawn> 0.9.1-2.mga3
+ Revision: 299125
- new rpm group for ocaml

* Sun Sep 09 2012 blue_prawn <blue_prawn> 0.9.1-1.mga3
+ Revision: 291356
- updated to last version 0.9.1

* Sun May 06 2012 blue_prawn <blue_prawn> 0.9.0-1.mga3
+ Revision: 234847
- imported package ocaml-uutf

